Example
=======

Example Gallery
---------------

.. nblinkgallery::
   :caption: Emprical Risk Minimization
   :name: rst-link-gallery

   examples/QR.ipynb
   examples/QR_eps.ipynb
   examples/CQR.ipynb
   examples/SVM.ipynb
   examples/FairSVM.ipynb
   examples/SVR.ipynb
   examples/RankRegression.ipynb
   examples/Path_solution.ipynb
   examples/Warm_start.ipynb
   examples/Sklearn_Mixin.ipynb
   examples/Multiclass_Classification.ipynb   
   examples/NMF.ipynb

List of Examples
----------------

.. toctree::
   :maxdepth: 1

   examples/QR.ipynb
   examples/QR_eps.ipynb
   examples/CQR.ipynb
   examples/SVM.ipynb
   examples/FairSVM.ipynb
   examples/SVR.ipynb
   examples/RankRegression.ipynb
   examples/Path_solution.ipynb
   examples/Warm_start.ipynb
   examples/Sklearn_Mixin.ipynb
   examples/Multiclass_Classification.ipynb 
   examples/NMF.ipynb
